@@ -345,14 +345,7 @@ public:
                      const Abc::Argument &iArg1 = Abc::Argument(),
                      const Abc::Argument &iArg2 = Abc::Argument() );
 
-    //! Copy constructor.
-    OSubDSchema(const OSubDSchema& iCopy)
-        : OGeomBaseSchema<SubDSchemaInfo>()
-    {
-        *this = iCopy;
-    }
-
-    //! Default assignment operator used.
+    //! Default assignment and copy operator used.
 
     //-*************************************************************************
     // SCHEMA STUFF
